Learn R Programming

ShrinkCovMat (version 2.1.0)

ShrinkCovMat-package: Shrinkage Covariance Matrix Estimators

Description

Provides nonparametric Stein-type shrinkage estimators of the covariance matrix that are suitable and statistically efficient when the number of variables is larger than the sample size. These estimators are non-singular and well-conditioned regardless of the dimensionality.

Arguments

Author

Anestis Touloumis Maintainer: Anestis Touloumis <A.Touloumis@brighton.ac.uk>

Details

Each of the implemented shrinkage covariance matrix estimators is a convex linear combination of the sample covariance matrix and of a target matrix.

The function shrinkcovmat implements three options for the target matrix: (a) spherical sample covariance matrix, i.e. the diagonal matrix with diagonal elements the average of the sample variances, (b) diagonal sample covariance matrix, i.e. the diagonal matrix with diagonal elements the corresponding sample variances, and (c) the identity matrix (identity). The optimal shrinkage intensity determines how much the sample covariance matrix will be shrunk towards the selected target matrix.

Estimation of the corresponding optimal shrinkage intensities is discussed in Touloumis (2015). The function targetselection is designed to ease the selection of the target matrix.

References

Touloumis, A. (2015) Nonparametric Stein-type Shrinkage Covariance Matrix Estimators in High-Dimensional Settings. Computational Statistics & Data Analysis 83, 251--261.

See Also