Learn R Programming

ShrinkCovMat (version 1.1.2)

shrinkcovmat.equal: Shrinking the Sample Covariance Matrix Towards a Diagonal Matrix with Equal Diagonal Elements

Description

Provides a nonparametric Stein-type shrinkage estimator of the covariance matrix that is a linear combination of the sample covariance matrix and of a diagonal matrix with the average of the sample variances on the diagonal and zeros elsewehere.

Usage

shrinkcovmat.equal(data, centered = FALSE)

Arguments

data

a numeric matrix containing the data.

centered

a logical indicating if the mean vector is the zero vector.

Value

Returns an object of the class "shrinkcovmathat" that has components:

Sigmahat

The Stein-type shrinkage estimator of the covariance matrix.

lambdahat

The estimated optimal shrinkage intensity.

Sigmasample

The sample covariance matrix.

Target

The target covariance matrix.

centered

If the data are centered around their mean vector.

Details

The rows of the data matrix data correspond to variables and the columns to subjects.

References

Touloumis, A. (2015) Nonparametric Stein-type Shrinkage Covariance Matrix Estimators in High-Dimensional Settings. Computational Statistics & Data Analysis 83, 251--261.

See Also

shrinkcovmat.unequal and shrinkcovmat.identity.

Examples

Run this code
# NOT RUN {
data(colon)
normal.group <- colon[, 1:40]
colon.group <- colon[, 41:62]
Sigmahat.normal <- shrinkcovmat.equal(normal.group)
Sigmahat.normal
Sigmahat.colon <- shrinkcovmat.equal(colon.group)
Sigmahat.colon
# }

Run the code above in your browser using DataLab