Provides a nonparametric Stein-type shrinkage estimator of the covariance matrix that is a linear combination of the sample covariance matrix and of a diagonal matrix with the average of the sample variances on the diagonal and zeros elsewhere.
shrinkcovmat.equal(data, centered)Returns an object of the class 'shrinkcovmathat' that has components:
The Stein-type shrinkage estimator of the covariance matrix.
The estimated optimal shrinkage intensity.
The sample covariance matrix.
The target covariance matrix.
If the data are centered around their mean vector.
a numeric matrix containing the data.
a logical indicating if the mean vector is the zero vector.
Anestis Touloumis
The rows of the data matrix data correspond to variables and the
columns to subjects.
Touloumis, A. (2015) nonparametric Stein-type Shrinkage Covariance Matrix Estimators in High-Dimensional Settings. Computational Statistics & Data Analysis 83, 251--261.
shrinkcovmat.unequal and
shrinkcovmat.identity.
ShrinkCovMat-deprecated