shrinkcovmat.unequal: Shrinking the Sample Covariance Matrix Towards a Diagonal Matrix with Diagonal Elements the Sample Variances.
Description
This function provides a nonparametric Stein-type shrinkage estimator of the covariance matrix that is a linear combination of the sample covariance matrix and of the diagonal matrix with diagonal elements the corresponding sample variances.
Usage
shrinkcovmat.unequal(data, centered = FALSE)
Arguments
data
a numeric matrix containing the data.
centered
a logical indicating if the vectors are centered around their mean vector.
Value
Returns an object of the class "covmat" that has components:
SigmahatThe Stein-type shrinkage estimator of the covariance matrix.
centeredIf the data are centered around their mean vector.
Details
The rows of the data matrix data correspond to variables and the columns to subjects.
References
Touloumis, A. (2014). Nonparametric Stein-type Shrinkage Covariance Matrix Estimators in High-Dimensional Settings. To appear in Computational Statistics and Data Analysis, http://arxiv.org/abs/1410.4726.