Learn R Programming

ShrinkCovMat (version 1.1.2)

ShrinkCovMat-package: Shrinkage Covariance Matrix Estimators

Description

Provides nonparametric Stein-type shrinkage estimators of the covariance matrix that are suitable and statistically efficient when the number of variables is larger than the sample size. These estimators are non-singular and well-conditioned regardless of the dimensionality.

Arguments

Details

Each of the implemented shrinkage covariance matrix estimators is a convex linear combination of the sample covariance matrix and of a target matrix. Three options are considered for the target matrix: (a) the diagonal matrix with diagonal elements the average of the sample variances (shrinkcovmat.equal), (b) the diagonal matrix with diagonal elements the corresponding sample variances (shrinkcovmat.unequal), and (c) the identity matrix (shrinkcovmat.identity). The optimal shrinkage intensity determines how much the sample covariance matrix will be shrunk towards the selected target matrix. Estimation of the corresponding optimal shrinkage intensities is discussed in Touloumis (2015). The function (targetselection) is designed to ease the selection of the target matrix.

References

Touloumis, A. (2015) Nonparametric Stein-type Shrinkage Covariance Matrix Estimators in High-Dimensional Settings. Computational Statistics & Data Analysis 83, 251--261.

See Also

shrinkcovmat.equal, shrinkcovmat.unequal, shrinkcovmat.identity and targetselection.

Examples

Run this code
# NOT RUN {
data(colon)
## Estimating the covariance matrix for the
## normal tissue group.
normal.group <- colon[, 1:40]
Sigmahat1 <- shrinkcovmat.equal(normal.group)
Sigmahat1
Sigmahat2 <- shrinkcovmat.identity(normal.group)
Sigmahat2
Sigmahat3 <- shrinkcovmat.unequal(normal.group)
Sigmahat3
# }

Run the code above in your browser using DataLab