Learn R Programming

ShrinkCovMat (version 1.0.3)

ShrinkCovMat-package: Shrinkage Covariance Matrix Estimators

Description

This package provides nonparametric Stein-type shrinkage estimators of the covariance matrix that are suitable and statistically efficient when the number of variables is larger than the sample size. These estimators are non-singular and well-conditioned regardless of the dimensionality.

Arguments

Details

Each of the implemented shrinkage covariance matrix estimators is a convex linear combination of the sample covariance matrix and of a target matrix. Three options are allowed for the target matrix: (a) the diagonal matrix with diagonal elements the average of the sample variances (shrinkcovmat.equal), (b) the diagonal matrix with diagonal elements the corresponding sample variances (shrinkcovmat.unequal), and (c) the identity matrix (shrinkcovmat.identity). The optimal shrinkage intensity determines how much the sample covariance matrix will be shrunk towards the selected target matrix. Estimation of the corresponding optimal shrinkage intensities is described in Touloumis (2014). The function (targetselection) might be useful for selecting one of the above target matrices.

References

Touloumis, A. (2014). Nonparametric Stein-type Shrinkage Covariance Matrix Estimators in High-Dimensional Settings. Computational Statistics and Data Analysis, http://dx.doi.org/10.1016/j.csda.2014.10.018.

See Also

shrinkcovmat.equal, shrinkcovmat.unequal, shrinkcovmat.identity and targetselection.

Examples

Run this code
data(colon)
## Estimating the covariance matrix for the normal tissue group.
normal.group <- colon[,1:40]
Sigma1 <- shrinkcovmat.equal(normal.group)
Sigma1
Sigma2 <- shrinkcovmat.identity(normal.group)
Sigma2
Sigma3 <- shrinkcovmat.unequal(normal.group)
Sigma3

Run the code above in your browser using DataLab