Learn R Programming

ShrinkCovMat (version 1.0.0)

ShrinkCovMat-package: Shrinkage Covariance Matrix Estimators

Description

This package provides nonparametric Stein-type shrinkage estimators of the covariance matrix that are suitable and statistically efficient when the number of variables is larger than the sample size. These estimators are non-singular and well-conditioned regardless of the dimensionality.

Arguments

Details

The Stein-type shrinkage covariance estimator is a convex linear combination of the sample covariance matrix and of a target matrix. This package implements the following three option for the target matrix: (a) a diagonal matrix with elements the average of the diagonal elements of the sample covariance matrix (shrinkcovmat.equal), (b) a diagonal matrix with elements the corresponding diagonal elements of the sample covariance matrix (shrinkcovmat.unequal), and (c) the identity matrix (shrinkcovmat.identity). The optimal shrinkage intensity determines how much the sample covariance matrix will be shrunk towards the selected target matrix. Estimation of the shrinkage intensity is described in Touloumis (2014).

References

Touloumis, A. (2014). Nonparametric Stein-type shrinkage covariance matrix estimators in high-dimensional settings. Submitted.

See Also

shrinkcovmat.equal, shrinkcovmat.unequal and shrinkcovmat.identity.

Examples

Run this code
data(colon)
## Estimating the covariance matrix for the normal tissue group.
normal.group <- colon[,1:40]
Sigma1 <- shrinkcovmat.equal(normal.group)
Sigma1
Sigma2 <- shrinkcovmat.identity(normal.group)
Sigma2
Sigma3 <- shrinkcovmat.unequal(normal.group)
Sigma3

Run the code above in your browser using DataLab