Options for the target matrix include the spherical sample covariance
matrix (the diagonal matrix with diagonal elements the average of the sample
variances), the diagonal sample covariance matrix (the diagonal matrix
with diagonal elements the corresponding sample variances), and (c) the
identity matrix.
The rows of the data matrix data correspond to variables/features and
the columns to subjects.
To select the target covariance matrix see targetselection.