shrinkcovmat.equal: Shrinking the Sample Covariance Matrix Towards a Diagonal Matrix with Equal Elements
Description
This function provides a nonparametric Stein-type shrinkage estimator of the covariance matrix that is a linear combination of the sample covariance matrix and of a diagonal matrix with elements the average of the diagonal elements of the sample covariance matrix.
Usage
shrinkcovmat.equal(data, centered = FALSE)
Arguments
data
a numeric matrix containing the data.
centered
a logical indicating if the mean vector is the zero vector.
Value
Returns an object of the class "covmat" that has components:
SigmahatThe Stein-type shrinkage estimator of the covariance matrix.